<?php
/*
Plugin Name: EditionGuard eBook Sales with DRM
Plugin URI: http://www.editionguard.com
Description: This plugin is a complete eBook sales solution, which is fully integrated with our cost-effective EditionGuard DRM service. By following just a few simple steps, you can immediately start selling your eBooks on your Wordpress site using Paypal, with industry standard eBook DRM protection.
Version: 1.1.2
Author: Kodelite LLC <info@kodelite.com>
Author URI: http://www.kodelite.com
License: GPL2

Copyright 2012 Kodelite LLC (email: info@kodelite.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2, as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/**
* public constant for plugins base url
*
* @var string 
* @access public
*/
define('BASE_URL', plugins_url() . '/' . basename(dirname(__FILE__)));

/**
* public constant for plugins base directory
*
* @var string 
* @access public
*/
define('BASE_DIR', dirname(__FILE__));

/**
* public constant for plugins name
*
* @var string 
* @access public
*/
define('PLUGINS_NAME', basename(dirname(__FILE__)));

/**
* public constant for website url which come from wordpress site url option settings
*
* @var string url
* @access public
*/
define('SITE_URL', get_option('siteurl'));

/**
* public constant version number for plugins 
*
* @var float
* @access public
*/
define('VERSION', '1.1.0');

/**
* public constant for plugins details or support url
*
* @var string url
* @access public
*/
define('PLUGINS_WEBSITE', 'http://www.editionguard.com/');

global $table_prefix;
define('TABLE_EBOOKS', $table_prefix . 'editionguard_ebooks');
define('TABLE_EBOOKS_ORDERS', $table_prefix . 'editionguard_orders');
include('functions.php');
include('lib/editionguard.class.php');

add_action('init', 'add_plugins_resource');
function add_plugins_resource() {
   if ( is_admin() ) {
       
        //If admin user interface/screen
        include_once('management/editionguard_general_settings.php');
        
        
        // Don't bother doing this stuff if the current user lacks permissions
       if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') )
         return;
     
       // Add only in Rich Editor mode
       if ( get_user_option('rich_editing') == 'true') {
         add_filter("mce_external_plugins", "add_editionguard_shortcode_plugin");
         add_filter('mce_buttons', 'register_editionguard_shortcode_button');
       }
       
   } else {
       
        /*
        *
        * Loading plugins required javascript files here for front end
        * */
        add_action('wp_print_scripts', 'enqueue_editionguard_scripts');
        
        /*
        *
        * Locading plugins required css files here for front-end
        * */
        add_action('wp_print_styles', 'enqueue_editionguard_styles');
   }
}

//Shortcode tinyMCE plugins code add
function add_editionguard_shortcode_plugin($plugin_array) {
   $plugin_array['ebook'] = BASE_URL.'/js/editor_editionguard_ebook_plugin.js';
   return $plugin_array;
} 
function register_editionguard_shortcode_button($buttons) {
   //array_push($buttons, "|", "scselect");
   array_push($buttons, "ebook");
   return $buttons;
}


// Add the filter
add_filter('upload_mimes', 'extended_mime_types');

function extended_mime_types($mimes) {
    $mimes['epub'] = "application/epub+zip";
    $mimes['pdf'] = "application/pdf";
    return $mimes;
}


//Loading required javascript files
function enqueue_editionguard_scripts() {
    //Plugins required Custom js code will goes in this js file
    wp_enqueue_script('editionguard_js', BASE_URL . "/js/editionguard-scripts.js", array('jquery'));
}

//Loading required css files
function enqueue_editionguard_styles() {
    //Plugins required custom CSS code will goes in this css file
    wp_enqueue_style('editionguard_css', BASE_URL . "/css/style.css", 100);
}

//Plugins installation process starts here!
register_activation_hook(__FILE__,'editionguard_install');
register_activation_hook(__FILE__,'editionguard_install_options');        


//creating plugins required database table when activating the plugins
function editionguard_install() {
   global $wpdb;
   
   
  if ($wpdb->get_var("SHOW TABLES LIKE '".TABLE_EBOOKS."'") != TABLE_EBOOKS) {
        //Creating database ebook table 
        $sql = "CREATE TABLE ".TABLE_EBOOKS." (
                      `id` int(11) NOT NULL AUTO_INCREMENT,
                      `user_id` int(11) NOT NULL,
                      `title` varchar(120) NOT NULL,
                      `author` varchar(120) DEFAULT NULL,
                      `publisher` varchar(120) DEFAULT NULL,
                      `sale_price` double NOT NULL,
                      `currency_code` varchar(20) NOT NULL DEFAULT 'USD',
                      `description` text,
                      `file` varchar(255) NOT NULL,
                      `status` enum('active','inactive') NOT NULL DEFAULT 'active',
                      `resource_id` varchar(255) DEFAULT NULL,
                      `created` datetime DEFAULT NULL,
                      `updated` datetime DEFAULT NULL,
                      PRIMARY KEY (`id`)
        ) ENGINE=InnoDB  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;";     
        $wpdb->query($sql);
    }
    
    
    
    
  if ($wpdb->get_var("SHOW TABLES LIKE '".TABLE_EBOOKS_ORDERS."'") != TABLE_EBOOKS_ORDERS) {
        //Creating database ebook orders
            $sql = "CREATE TABLE IF NOT EXISTS ".TABLE_EBOOKS_ORDERS." (
              `id` int(11) NOT NULL AUTO_INCREMENT,
              `ebook_id` int(11) NOT NULL,
              `ebook_title` varchar(255) NOT NULL,
              `first_name` varchar(120) NOT NULL,
              `last_name` varchar(120) NOT NULL,
              `email` varchar(200) NOT NULL,
              `amount` float NOT NULL,
              `payment_status` enum('Pending','Successful','Unsuccessful','Failed','Denied','Refunded','Canceled') NOT NULL DEFAULT 'Pending',
              `payment_method` varchar(120) DEFAULT NULL,
              `payment_currency` varchar(20) DEFAULT NULL,
              `order_status` enum('Waiting','Completed') NOT NULL DEFAULT 'Waiting',
              `download_link` varchar(255) DEFAULT NULL,
              `created` datetime NOT NULL,
              `ipn_data` text,
              PRIMARY KEY (`id`)
            ) ENGINE=InnoDB  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;";
        $wpdb->query($sql);  
  }    
}


//adding plugins required all settings options here when activating the plugins
function editionguard_install_options(){
    
    //Editionguard General settings
    if(!get_option('settings_general_editionguard_account_email'))
        add_option('settings_general_editionguard_account_email', 'editionguard@email.com', '', 'no');       // EditionGuard Account E-Mail 
    
    if(!get_option('settings_general_distributor_id'))
        add_option('settings_general_distributor_id', 'XXXXXXXXXX', '', 'no');       // Distributor Id 
    
    if(!get_option('settings_general_shared_secret'))
        add_option('settings_general_shared_secret', 'XXXXXXXXXX', '', 'no');     // Shared Secret
    
    //if(!get_option('settings_general_checkout_page_id'))
        //add_option('settings_general_checkout_page_id', '5', '', 'no');     // Checkout Page ID
    
    if(!get_option('settings_general_checkout_email_sender_name'))
        add_option('settings_general_checkout_email_sender_name', 'Support', '', 'no');     // Email sender name 
    
    if(!get_option('settings_general_checkout_email_sender_email'))
        add_option('settings_general_checkout_email_sender_email', 'sender@email.com', '', 'no');     // Email sender email address
    
    if(!get_option('settings_general_payment_notify_email'))
        add_option('settings_general_payment_notify_email', 'notify@email.com', '', 'no');     // Payment notify email address
    
    
    //Paypal settings 
    if(!get_option('settings_paypal_email'))
        add_option('settings_paypal_email', 'paypal@email.com', '', 'no');       // Paypal E-Mail Address 
    
    if(!get_option('settings_paypal_test_mode'))
        add_option('settings_paypal_test_mode', 'Yes', '', 'no');     // Test Mode
    
    
    
    
    //Plugins Version!
    if(!get_option('editionguard_plugins_version'))
        add_option("editionguard_plugins_version", VERSION, '', 'no');     //adding plugins database verions
        
    //Updating plugins version     
    $installed_ver = get_option( "editionguard_plugins_version" );
    if( $installed_ver != VERSION ) {
      update_option( "editionguard_plugins_version", VERSION );
    }           
}


/**
* To generate Information display box on admin interface
* 
* @param title string Information box title
* @param message string Information content
* @return string
* @access public
*/
function editionguard_box($title, $message) {
     return "
        <div id=\"poststuff\" style=\"margin-left:10px;\">
        <div class=\"postbox\">
        <h3>$title</h3>
        <table class='form-table'>
        <td>$message</td>
        </table>
        </div></div>
        ";
}

/**
* To generate plugins information menu on admin interface
* 
* @return string
* @access public
*/
function editionguard_version_line(){
    return "";
    return "" .
    " <h4 align=\"right\" style=\"margin-right:0.5%\">" .
       " &nbsp;Version: <b>" . VERSION . "</b> |" .
        " <a href=\"".PLUGINS_WEBSITE."\">Support</a> |" .
        " <a href=\"http://wordpress.org/extend/plugins/".PLUGINS_NAME."/faq/\">FAQ</a> |" .
        " <a href=\"http://wordpress.org/extend/plugins/".PLUGINS_NAME."/\">Rate this plugin</a> |" .
        " <a href=\"http://wordpress.org/extend/plugins/".PLUGINS_NAME."/changelog/\">Changelog</a> |" .
        " <a href=\"http://wp.editionguard.com\">Live Demo</a>" .
    " </h4>";
}


/**
* To generate markup for showing current general settings preview on admin interface
* 
* @return string
* @access public
*/
function editionguard_general_settings_box() {
    global $wpdb, $post, $wp;    
    $page_id = get_option('settings_general_checkout_page_id');
    $pages = get_pages();    
    if(!empty($page_id)){
        foreach($pages as $page){
            if($page_id == $page->ID){
                $page_name = $page->post_title;
            }
        }
    } else {
        $page_name = 'N/A';
    }
    
    $message = "EditionGuard Account E-Mail - <b>" . get_option('settings_general_editionguard_account_email') . "</b>";
    $message .= "<br />Shared Secret - <b>" . get_option('settings_general_shared_secret') . "</b>";
    //$message .= "<br />Checkout Page ID - <b>" . $page_name . "</b>";
    $message .= "<br />Sender Name - <b>" . get_option('settings_general_checkout_email_sender_name') . "</b>";
    $message .= "<br />Sender E-Mail - <b>" . get_option('settings_general_checkout_email_sender_email') . "</b>";
    $message .= "<br />Payment Notify E-Mail - <b>" . get_option('settings_general_payment_notify_email') . "</b>";
    return editionguard_box('Current Settings', $message);
}


/**
* To generate markup for showing current paypal settings preview on admin interface
* 
* @return string
* @access public
*/
function editionguard_paypal_settings_box() {
    $message = "E-Mail Address - <b>" . get_option('settings_paypal_email') . "</b>";
    $message .= "<br />Test Mode - <b>" . get_option('settings_paypal_test_mode') . "</b>";
    return editionguard_box('Current Settings', $message);
}

/**
* Getting plugins settings all options in a array 
* 
* @return array
* @access public
*/
function editionguard_get_all_options() {
    return array(
        'settings_general_editionguard_account_email' => get_option('settings_general_editionguard_account_email'),
        'settings_general_shared_secret' => get_option('settings_general_shared_secret'),
        //'settings_general_checkout_page_id' => get_option('settings_general_checkout_page_id'),
        
        
        'settings_general_checkout_email_sender_name' => get_option('settings_general_checkout_email_sender_name'),
        'settings_general_checkout_email_sender_email' => get_option('settings_general_checkout_email_sender_email'),
        'settings_general_payment_notify_email' => get_option('settings_general_payment_notify_email'),
        
        
        'settings_paypal_email' => get_option('settings_paypal_email'),
        'settings_paypal_test_mode' => get_option('settings_paypal_test_mode'),
                                                                                 
                                                                                  
        'editionguard_plugins_version' => get_option('editionguard_plugins_version'),
    );
}




















//define('EBOOK_PAYMENT_PAGE_ID', get_option('settings_general_checkout_page_id')); 






add_shortcode('ebook', 'editionguard_ebook_shortcode');
function editionguard_ebook_shortcode( $atts, $content = null ){
    global $wpdb, $post, $wp;
    extract( shortcode_atts(array("payment" => 'both', "id" => '0'), $atts) );
    
    $output = '';
    if(!empty($_REQUEST['payment'])){
        //On eBook Payment Page!
        $payment = $_REQUEST['payment'];
        $ebook_id = $_REQUEST['ebook_id'];
        $output.= do_shortcode("[ebook_details payment=$payment id=$ebook_id]"); 
        return $output;
    }
    
    
    if($id<=0){
        return '<span class="empty_shortcode_result">Invalid ebook id provided!<span>';
    } else {
        $sql="select * from ".TABLE_EBOOKS." where id='".$id."' and status='active'";
        $ebook_data=$wpdb->get_row($sql);
    }
    
    if(empty($ebook_data)){
        return '<span class="empty_shortcode_result">Invalid ebook id provided or ebook is not ready for sell!<span>';             
    }
    
    $title = $ebook_data->title;
    $author = $ebook_data->author;
    $publisher = $ebook_data->publisher;
    $sale_price = $ebook_data->sale_price;
    $description = $ebook_data->description;
    $currency_code = $ebook_data->currency_code;
    
    
    $output.= '<div class="ebook_container">';
        $output.= '<h2>'.$title.'</h2>';    
        
        if(!empty($author) || !empty($publisher)){
            $output.= '<div class="ebook_meta_data">';
                if(!empty($author))
                $output.= ' <span class="author"><b>Author:</b> '.$author.'</span><br/>';
                if(!empty($publisher))
                $output.= ' <span class="publisher"><b>Publisher:</b> '.$publisher.'</span>';
            $output.= '</div>';    
        }
        
        $output.= '<div class="ebook_meta_data"><span class="price"><b>Sale Price:</b> '.$sale_price.' '.$currency_code.'</span></div>';    
        
        if(!empty($description))
        $output.= '<p>'.$description.'</p>';         
    
        
        $output.= '<div class="ebook_payment_buttons">';
            if($payment=='paypal' || $payment=='both'){
                $payment_page_uri = add_query_arg( 'payment', 'paypal', get_permalink() );        
                $payment_page_uri = add_query_arg( 'ebook_id', $id, $payment_page_uri );         
                //$output.='<span class="paypal_button pbuttons"><a href="'.$payment_page_uri.'">Purchase via Paypal</a></span>';    
                $output.='<a href="'.$payment_page_uri.'#ebook_details"><input class="paypal_pay_button" type="submit" value="Purchase"></a>';    
            }
            
        $output.= '</div>';  
        
                    
    $output.= '</div>';      
    return $output;
} 



add_shortcode('ebook_details', 'editionguard_ebook_details_shortcode');
function editionguard_ebook_details_shortcode( $atts, $content = null ){
    global $wpdb, $post, $wp;
    extract( shortcode_atts(array("payment" => 'paypal', "id" => '0'), $atts) );
    
    if($id<=0){
        return '<span class="empty_shortcode_result">Invalid ebook id provided!<span>';
    } else {
        $sql="select * from ".TABLE_EBOOKS." where id='".$id."' and status='active'";
        $ebook_data=$wpdb->get_row($sql);
    }
    
    if('paypal' == $payment){
        
    } else {
        return '<span class="empty_shortcode_result">Invalid ebook purchase payment method!<span>';             
    }
    
    
    if(empty($ebook_data)){
        return '<span class="empty_shortcode_result">Invalid ebook id provided or ebook is not ready for sell!<span>';             
    }
    
    
    $editionguard_options = editionguard_get_all_options();
    $title = $ebook_data->title;
    $author = $ebook_data->author;
    $publisher = $ebook_data->publisher;
    $sale_price = $ebook_data->sale_price;
    $description = $ebook_data->description;
    $currency_code = $ebook_data->currency_code;        
    
    $output='';
    
    $output.= '<a name="ebook_details" /><br/><div class="ebook_details_container">';
        $output.= '<h2>'.$title.'</h2>';   
        
        if(!empty($author) || !empty($publisher)){
            $output.= '<div class="ebook_meta_data">';
                if(!empty($author))
                $output.= ' <span class="author"><b>Author:</b> '.$author.'</span><br/>';
                if(!empty($publisher))
                $output.= ' <span class="publisher"><b>Publisher:</b> '.$publisher.'</span>';
            $output.= '</div>';    
        }
         
        $output.= '<div class="ebook_meta_data"><span class="price"><b>Sale Price:</b> '.$sale_price.' '.$currency_code.'</span></div>';    
        
        if(!empty($description))
        $output.= '<p>'.$description.'</p>';         
                                                       
                                                       
        $output.= '<div class="ebook_payment_buttons">';
            if($payment=='paypal'){
                include('lib/payment/paypal/button.php');
                $output.= $button_output;              
            } else {
                $output.= 'No Payment Defined!';
            }
        $output.= '</div>';  
        
                    
    $output.= '</div>';      
    return $output;
} 





add_shortcode('ebook_payment', 'editionguard_ebook_payment_shortcode');
function editionguard_ebook_payment_shortcode( $atts, $content = null ){
    global $wpdb, $post, $wp;
    $output = '';
    if(!empty($_REQUEST['payment'])){
        //On eBook Payment Page!
        $payment = $_REQUEST['payment'];
        $ebook_id = $_REQUEST['ebook_id'];
        $output.= do_shortcode("[ebook_details payment=$payment id=$ebook_id]"); 
    }
    
    return $output;
}

//add_filter('query_vars', 'wftp_vars');
 
function wftp_vars($public_query_vars) {
    $public_query_vars[] = 'ebook_id';
    $public_query_vars[] = 'payment';
    $public_query_vars[] = 'action';
    return $public_query_vars;
}

function eg_curl_it($uri, $data, $method = 'POST')
  {
  if($method=='GET') $uri .= (!empty($data)) ? "?$data" : "";
  $ch = curl_init();
  curl_setopt($ch, CURLOPT_URL, $uri);
  curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
  curl_setopt($ch, ($method=='GET') ? CURLOPT_HTTPGET : CURLOPT_POST, 1);
  if($method!='GET') curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
  $ret = curl_exec($ch);
  curl_close($ch);
  return $ret;
  } 
