<?php 
/* 
 * editionguard.class.php 
 *  
 * Copyright 2012 Kodelite LLC <info@kodelite.com> 
 *  
 * This program is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version. 
 *  
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 * GNU General Public License for more details. 
 *  
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
 * MA 02110-1301, USA. 
 *  
 * Date: 30-Aug-2012 
 */ 
class editionguard 
{ 
    private $shared_secret; 
    private $account_email;   
    public $error_msg = '';
    public $success_msg = '';
    public $error = false;
    public $success = false;
     
    function __construct($shared_secret=null,$account_email=null) 
    { 
        $this->shared_secret=$shared_secret; 
        $this->account_email=$account_email;                     
    } 
    
    /*
    * 
    * @ param string $msg to enque the msg string
    * @ return void
    * @ access public
    * */  
    public function set_error($msg){
        $this->error = true;
        $this->error_msg = $msg;
    }
    
    /*
    * 
    * @ param string $msg to enque the msg string
    * @ return void
    * @ access public
    * */  
    public function set_success($msg){
        $this->success = true;
        $this->success_msg = $msg;
    }
    
    /*
    * 
    * @ param int $ebook_id ebook id from local record database table
    * @ param string $resouce_id resouce id returned by editionguard when packaging
    * @ return string ebook download link
    * @ access public
    * */
    public function fulfillment($order_id, $resource_id){
        $dateval=time(); 
        
        $secret = $this->shared_secret; // Place your unique distributor shared secret, keep this safe or the api can be used in your stead by others!
        $transactionId = $order_id; // Must be a unique value, generated by you for your records
        $resourceId = $resource_id; // Place Content Server Resource ID starting with urn:uuid:
        $linkURL = "http://acs4.editionguard.com/fulfillment/URLLink.acsm"; // Content server service url, do not change.
        $orderSource = $this->account_email; // Your EditionGuard subscription e-mail address.
        
        // Create download URL
        $URL = "action=enterorder&ordersource=".urlencode($orderSource)."&orderid=".urlencode($transactionId)."&resid=".urlencode("$resourceId")."&dateval=".urlencode($dateval)."&gblver=4";

        // Digitaly sign the request
        $URL = $linkURL."?".$URL."&auth=".hash_hmac("sha1", $URL, base64_decode($secret));
        
        return $URL;
    }
    
    
    /*
    * 
    * @ param string $resource_id required resouce id returned by editionguard when packaging 
    * @ return editionguard returned value
    * @ access public
    * */ 
    public function status($status, $resource_id = null){
        
        if(empty($resource_id)){
            $this->set_error('Resource Id field can not be blank to update a ebook status.'); 
            return false;
        }
        
        $valid_status = array('active', 'inactive');
        if (!in_array($status, $valid_status)) {
            $this->set_error('Status string is not valid. Ex Status: active, inactive.'); 
            return false;
        }

        
        $secret = $this->shared_secret;
        $email = $this->account_email;
        $nonce = rand(1000000, 999999999); // Random nonce value
        $hash = hash_hmac("sha1", $nonce.$email, base64_decode($secret)); 
        $url = "http://www.editionguard.com/api/set_status";
        $data = array(
            'email' => $email, 
            'nonce'=>$nonce,  
            'hash'=>$hash,                       
            'resource_id'=>$resource_id,
            'status'=>$status
            );   
        $return_string = $this->getPagePost($url, $data);   
        $this->set_success('Success!');      
        return $return_string;
    }
    
    /*
    * 
    * @ param string $resource_id required resouce id returned by editionguard when packaging 
    * @ return editionguard returned value
    * @ access public
    * */ 
    public function delete($resource_id = null){
        
        if(empty($resource_id)){
            return;
        }
        
        $secret = $this->shared_secret;
        $email = $this->account_email;
        $nonce = rand(1000000, 999999999); // Random nonce value
        $hash = hash_hmac("sha1", $nonce.$email, base64_decode($secret)); 
        $url = "http://www.editionguard.com/api/delete";
        $data = array(
            'email' => $email, 
            'nonce'=>$nonce,  
            'hash'=>$hash,                       
            'resource_id'=>$resource_id
            );   
        $return_string = $this->getPagePost($url, $data);   
        $this->set_success('Success!');      
        return $return_string;
    }
    
    /*
    * 
    * @ param array $package package title, author, publisher, file etc all are reuired for a successfull request!
    * @ return boolean false if it is an unsuccessful request elase resource id
    * @ access public
    * */ 
    public function packaging($package = array()) {
        
        if(empty($package)){
            $this->set_error('Invalid packaging request parameters.');
            return false;
        }
        
        if(empty($package['title'])){
            $this->set_error('Package title field can not be blank.');
            return false;
        }
        
        /*if(empty($package['author'])){
            $this->set_error('Package author field can not be blank.');            
            return false;
        }
        
        if(empty($package['publisher'])){
            $this->set_error('Package publisher field can not be blank.');  
            return false;
        }*/
        
        if(empty($package['file'])){
            $this->set_error('Package pdf file field can not be blank.'); 
            return false;
        }
        
        $secret = $this->shared_secret;
        $email = $this->account_email;
        $nonce = rand(1000000, 999999999); // Random nonce value
        $hash = hash_hmac("sha1", $nonce.$email, base64_decode($secret)); 
        $url = "http://www.editionguard.com/api/package";
        $file = $package['file'];
        $data = array(
            'email' => "$email", 
            'nonce'=>"$nonce",  
            'hash'=>"$hash",  
            'title'=>$package['title'],  
            'author'=>$package['author'],  
            'publisher'=>$package['publisher'],  
            'resource_id'=>$package['resource_id'],  
            'file' => "$file"
            );   
            
            
            
        $return_string = $this->getPagePost($url, $data);              
         
          
/*
//Successful request   
<resourceItemInfo xmlns="http://ns.adobe.com/adept">
<resource>urn:uuid:xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx</resource>
<resourceItem>0</resourceItem>
<metadata>
<dc:title xmlns:dc="http://purl.org/dc/elements/1.1/">Book Title</dc:title>
<dc:creator xmlns:dc="http://purl.org/dc/elements/1.1/">Book Creator</dc:creator>
<dc:format xmlns:dc="http://purl.org/dc/elements/1.1/">application/pdf</dc:format>
<dc:publisher xmlns:dc="http://purl.org/dc/elements/1.1/">Book Publisher</dc:publisher>
</metadata>
<src>http://acs4.editionguard.com:8080/media/xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx.pdf</src>
<downloadType>simple</downloadType>
<licenseToken>
<resource>urn:uuid:xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx</resource>
<permissions>
<display/>
</permissions>
</licenseToken>
</resourceItemInfo>
*/     
/*
//Invalid request
<error xmlns="http://ns.adobe.com/adept" data="E_PACK_UNKNOWN_FILE_TYPE http://acs4.editionguard.com:8080/packaging/Package"/>
*/
            
            
             
        $errorstring = '<resource>';
        $pos = strpos($return_string, $errorstring);

        if ($pos === false) {
            $errorstring = 'Hash authentication';
            $pos = strpos($return_string, $errorstring);
            if ($pos === false) { 
                $this->set_error($return_string);        
                return false;
            } else {
                $this->set_error('Hash authentication failed! Please check your post variables.');        
                return false;
            }      
        } else {
            //Hash authentication failed! Please check your post variables.
            //Successful request!
            $resource_id = $this->getValueByTagName($return_string, '<resource>', '</resource>');
            $resource_id = trim($resource_id);
            $this->set_success('Success!');
                                            
            return $resource_id;
            
        }

        $this->set_error('There is an error with submitting packages to editionguard.');        
        return false;
    }
     
    
    /*
    * 
    * @ param string $url as 'http://maps.google.com'; Page url location which you want to fetch
    * @ param array  $data
    * @ param string $proxy [optional] as '[proxy IP]:[port]'; Proxy address and port number 
    * which you want to use
    * @ param string $userpass [optional] as '[username]:[password]'; Proxy authentication 
    * username and password
    * @ return a url page html content
    * @ access private
    * */
    private function getPagePost($url, $data = array(), $proxy='', $userpass='') {
     
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
     
        if(!empty($proxy))
        curl_setopt($ch, CURLOPT_PROXY, $proxy);
     
        if(!empty($userpass))
        curl_setopt($ch, CURLOPT_PROXYUSERPWD, $userpass);
     
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
        
        $result = curl_exec($ch);
        
        if($result === false)
        {
            $result = curl_error($ch);
        }
           
        
        curl_close($ch);
        return $result;
    }
    
    /*
    * 
    * @ param string $url as 'http://maps.google.com'; Page url location which you want to fetch
    * @ param string $proxy [optional] as '[proxy IP]:[port]'; Proxy address and port number 
    * which you want to use
    * @ param string $userpass [optional] as '[username]:[password]'; Proxy authentication 
    * username and password
    * @ return a url page html content
    * @ access private
    * */
     
    private function getPage($url, $proxy='', $userpass='') {
     
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
     
        if(!empty($proxy))
        curl_setopt($ch, CURLOPT_PROXY, $proxy);
     
        if(!empty($userpass))
        curl_setopt($ch, CURLOPT_PROXYUSERPWD, $userpass);
     
        $result = curl_exec($ch);
        curl_close($ch);
        return $result;
    }
     
    /*
    * 
    * @ param string $data Full html content which you want to parse
    * @ param string $s_tag Start tag of html content
    * @ param string $e_tag End tag of html content
    * @ return middle html content from given start tag and end tag of $data
    * @ access private
    * */
     
    private function getValueByTagName( $data, $s_tag, $e_tag) {
            $s = strpos( $data,$s_tag) + strlen( $s_tag);
            $e = strlen( $data);
            $data= substr($data, $s, $e);
            $s = 0;
            $e = strpos( $data,$e_tag);
            $data= substr($data, $s, $e);
            $data= substr($data, $s, $e);
            return  $data;
    }    
}    
